const debug=require('debug')('debug');

//start
debug('api start...');

require('dotenv').config();
const HELMET = require('helmet');
const COMPRESSION = require('compression');

const EXPRESS = require("express");
const CORS = require("cors");

const ROOTROUTER = require('./route/root');
const STOPS_GTFS_DE_ROUTER = require('./route/gtfs-stops-de');
const STOPS_GTFS_DE_NOT_DHID_ROUTER = require('./route/gtfs-stops-de-not-dhid');
const STOPS_GTFS_DE_NOT_DHID_REFINE_ROUTER = require('./route/gtfs-stops-de-not-dhid-refine');

const STOPS_COUNT_GTFS = require('./route/stops-count-gtfs');
const STOPS_COUNT_GTFS_DE = require('./route/stops-count-gtfs-de');
const STOPS_COUNT_GTFS_DE_NOT_DHID = require('./route/stops-count-gtfs-de-not-dhid');
const STOPS_COUNT_ZHV = require('./route/stops-count-zhv');

//TODO make this list available via config
//limit access to this origin list
let whitelist = [
    'http(s)://foo.bar'
];

const APP = EXPRESS();

//compress all routes
APP.use(COMPRESSION());

//protect against vulnerabilities
APP.use(HELMET());

//configure CORS
APP.use(CORS({
    origin: function(origin, callback){
        // allow requests with no origin
        debug('origin: '+origin)
        if(!origin){
            return callback(null, true);
        }
        if(whitelist.indexOf(origin) === -1){
            let message = 'The CORS policy for this origin does not allow access from the particular origin: '+origin;
            return callback(new Error(message), false);
        }
        debug('origin: '+origin+' allowed by CORS');
        return callback(null, true);
    }
}));

//api enable/disable?
APP.use('/', ROOTROUTER);
APP.use('/gtfs-stops-de',STOPS_GTFS_DE_ROUTER);
APP.use('/gtfs-stops-de-not-dhid',STOPS_GTFS_DE_NOT_DHID_ROUTER);
APP.use('/gtfs-stops-de-not-dhid-refine',STOPS_GTFS_DE_NOT_DHID_REFINE_ROUTER);

APP.use('/stops-count-gtfs',STOPS_COUNT_GTFS);
APP.use('/stops-count-gtfs-de',STOPS_COUNT_GTFS_DE);
APP.use('/stops-count-gtfs-de-not-dhid',STOPS_COUNT_GTFS_DE_NOT_DHID);
APP.use('/stops-count-zhv',STOPS_COUNT_ZHV);

module.exports=APP;

//end
debug('api done..');
